elephant.gpfa.gpfa.GPFA
=======================

.. currentmodule:: elephant.gpfa.gpfa

.. autoclass:: GPFA
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GPFA.__init__
      ~GPFA.fit
      ~GPFA.fit_transform
      ~GPFA.get_params
      ~GPFA.score
      ~GPFA.set_params
      ~GPFA.transform
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GPFA.binsize
   
   